/* ----------------------------------------------------------- */
/*                   HTK  -  HMM Toolkit                       */
/* ----------------------------------------------------------- */
/*         Copyright: Steve Young      October 1989            */
/*         Cambridge University Engineering Department         */
/*         Trumpington Street, Cambridge, CB2 1PZ              */
/*                                                             */
/* Permission is hereby granted to copy, use and modify this   */
/* software provided that this banner notice is not removed    */
/*                                                             */
/* ----------------------------------------------------------- */
/*      File: HDbase.h:   Training Database Management         */
/* ----------------------------------------------------------- */

/*
   This module provides for the storage and retrieval of training
   data.  It is intended for use in 'isolated word' styles of 
   training where all stored observation sequences correspond to
   the same segment
*/

void InitDbase(int vecSize, SampKind sampKind);
/*
   Initialise the database to store sequences of vectors of type
   sampKind and of size vecSize
*/

void CloseDbase(void);
/*
   Release memory buffer used by dbase and remove external temp file
*/

void PutSequence(long start, long end, DataFile *data);
/*
   Store the sequence of vectors in data covering the time 
   span start to end
*/

void FixDbase(void);
/*
   This must be called after all calls to PutSequence and before
   any calls to GetSequence
*/

int  NumSequences(void);
/*
   Total number of sequences currently stored in dbase
*/

int  SequenceLength(int index);
/*
   Return number of vectors in index'th sequence
*/

Vector GetDBVector(int index, int i);
/*
   Return the i'th vector in the index'th sequence, ranges are
   index: 0..NumSequences-1, i: 0..SequenceLength(index)-1. 
   VECTOR RETURNED IS NOT A COPY.  IT WILL BE VALID UNTIL GetDBVector
   IS CALLED WITH A DIFFERENT VALUE FOR index.
*/
   

/* ------------------------ End of HDbase.h ------------------------- */
