/* ----------------------------------------------------------- */
/*                   HTK  -  HMM Toolkit                       */
/* ----------------------------------------------------------- */
/*         Copyright: Steve Young      October 1989            */
/*         Cambridge University Engineering Department         */
/*         Trumpington Street, Cambridge, CB2 1PZ              */
/*                                                             */
/* Permission is hereby granted to copy, use and modify this   */
/* software provided that this banner notice is not removed    */
/*                                                             */
/* ----------------------------------------------------------- */
/*         File: HGraf.h:   Minimal Graphics Interface         */
/* ----------------------------------------------------------- */

/*
   This module provides a minimal graphics facility.  It provides a 
   single fixed window onto which the graphics and text can be painted.  
   
   The coordinate system used has (0,0) at the top left corner with
   x increasing left and y increasing down.  All draw operations use
   the current colour and current transfer mode.
*/

#define MAXGREYLEVEL 64
enum _Colour {WHITE,YELLOW,ORANGE,RED,MAUVE,PURPLE,DKBLUE,LTBLUE,
               LTGREEN,DKGREEN,DKBROWN,LTBROWN,LTGREY,GREY,DKGREY,BLACK};
typedef enum _Colour Colour;

enum _XferMode {GCOPY, GOR, GXOR};
typedef enum _XferMode XferMode;

void InitHGraf(int width, int height, char *name);
/*
   Create a window of given dimensions and name, and initialise 
   the module. Default colour is black, default transfer mode 
   is GCopy
*/

void TermGraf(void);
/*
   Close down graphics window and clean up.  This call is
   superfluous in vanilla ANSI C implementations which 
   implement at_exit.
*/
   
void HSetColour(Colour c);
void HSetGrey(int level);
/*
   Set current colour to c or the specified grey level
*/

void HSetXMode(XferMode m);
/*
   Set current transfer mode
*/

void HDrawLine(int x0,int y0,int x1,int y1);
/*
   Draw line from (x0,y0) to (x1,y1)
*/

void HDrawRect(int x0,int y0,int x1,int y1);
void HFillRect(int x0,int y0,int x1,int y1);
/*
   Draw rectangle with top-left at (x0,y0) and bottom
   right at (x1,y1)
*/

void HDrawArc(int x0,int y0,int x1,int y1,int stAngle,int arcAngle);
void HFillArc(int x0,int y0,int x1,int y1,int stAngle,int arcAngle);
/*
   Draw arc from stAngle degrees thru arcAngle degrees such that if
   arcAngle=360, the closed contour would just fit inside the rect
   with top-left at (x0,y0) and bottom right at (x1,y1).  Positive
   angles are anticlockwise and 0 degrees is along the positive x
   axis.
*/

void HSetTextSize(int size);
/*
   Set font size in points of current text
*/

void HDrawText(int x,int y, char *s);
/*
   Draw the given text string with the left side of the base line
   of the first character at (x,y)
*/

int HTextWidth(char *s);
/*
   Returns the width of the given string
*/

void HPlotVector(int x0,int y0,int x1,int y1, 
                 Vector v, int st, int en, float ymax, float ymin);
/*
   Plot the values from v[st]..v[en] within the rectangle defined 
   by x0,y0,x1,y1 such that peak values of ymax and ymin would just
   touch the top and bottom of the rectangle.  The plot is drawn
   the conventional way round ie positive values in the -ve y direction
*/

void HSpoolGraf(char *fname);
/*
   HSpoolGraf should be called immediately after InitHGraf.  It causes
   all subsequent draw ops to be saved in file fname as well as being
   drawn on the screen.
*/

/* ------------------------ End of HGraf.h ------------------------- */
