/* ----------------------------------------------------------- */
/*                   HTK  -  HMM Toolkit                       */
/* ----------------------------------------------------------- */
/*         Copyright: Steve Young      October 1989            */
/*         Cambridge University Engineering Department         */
/*         Trumpington Street, Cambridge, CB2 1PZ              */
/*                                                             */
/* Permission is hereby granted to copy, use and modify this   */
/* software provided that this banner notice is not removed    */
/*                                                             */
/* ----------------------------------------------------------- */
/*         File: HShell.h:   Interface to the Shell            */
/* ----------------------------------------------------------- */

#define UNIX    /* or UNIX or MSDOS or MPW or VMS */

enum _Boolean {FALSE,TRUE};
typedef enum _Boolean Boolean;

void InitShell(int argc, char *argv[]);
/* 
   Called from main to initialise module and store command line parameters 
   for subsequent access by following xxxArg routines
*/
   
enum _ArgKind {SWITCHARG, STRINGARG, INTARG, FLOATARG, NOARG};
typedef enum _ArgKind ArgKind;

int  NumArgs(void);
/*
   Returns number of command line args which have not yet been processed.
   Initially this is equal to argc-1 since actual command name is ignored
*/

ArgKind NextArg(void);
/*
   Returns the kind of the next command line argument.  If NumArgs()==0 then
   NOARG will be returned.
*/

void SetScriptFile(void);
/*
   Takes the next command line arg as the name of a script file.  This script
   file is then effectively appended to the command line (so NumArgs and NextArg
   may change after this call). Args in the script file are delimited by white
   space, single quotes may be used to include white space in the arg.
*/

char * GetStrArg(void);
char * GetSwtArg(void);
int    GetIntArg(void);
float  GetFltArg(void);
/*
   Return value of next arg and 'consume' that arg.  An error is raised if
   the kind of the next arg is different to that requested except that 
   GetFltArg will accept either an integer or a float argument
*/

void HError(int status, char *message, ...);
/*
   Print the given message in 'printf' style, then if status <>0 terminate
   with given status.  Allowable optional parameters in message are %d, %s
   and %c
*/

#ifdef MPW
   #define SPINBALL SpinCursor(32); 
   pascal void SpinCursor(short int);
#else
#define SPINBALL
#endif
/* 
   In MPW, this is called within computationally intensive tasks to allow
   background processing
*/

#if defined MPW
#define PATHCHAR ':'
#endif
#if defined UNIX
#define PATHCHAR '/'
#endif
#if defined MSDOS
#define PATHCHAR '\\'
#endif
#if defined VMS
#define PATHCHAR ']'
#endif

char * NameOf(char *fn, char *s);
char * BaseOf(char *fn, char *s);
char * PathOf(char *fn, char *s);
char * ExtnOf(char *fn, char *s);
/*
   Given a filename of the general form "path/n.x" in fn, the above
   functions return "n.x", "n", "x" and "path", respectively. In each case,
   the string is returned in s which must be large enough and s is returned
   as the function result.
*/

char * MakeFN(char *fn, char *path, char *ext, char *s);
/*
   The supplied file name fn is used as a template for constructing a 
   new file name returned in s as function result.  The construction
   rules are as follows:
      a) if path is not NULL then any path is stripped from fn and
         replaced by the given path
      b) if ext is not NULL then any extension is stripped from fn 
         and replaced by the given extension
*/

char *NewString(int size);
/*
   Returns a pointer to a malloc'ed string of given size
*/

/* -------------------------- End of HShell.h ----------------------------- */
