/* ----------------------------------------------------------- */
/*                   HTK  -  HMM Toolkit                       */
/* ----------------------------------------------------------- */
/*         Copyright: Steve Young      October 1989            */
/*         Cambridge University Engineering Department         */
/*         Trumpington Street, Cambridge, CB2 1PZ              */
/*                                                             */
/* Permission is hereby granted to copy, use and modify this   */
/* software provided that this banner notice is not removed    */
/*                                                             */
/* ----------------------------------------------------------- */
/*      File: HSigP.h:   Signal Processing Routines            */
/* ----------------------------------------------------------- */


#define MAXFRAMESIZE 2048     /* ie Max samples in a frame of speech */
#define MAXFEATURES 64        /* ie Max components in a feature vector */

void Ham (Vector s);
/*
   Apply Hamming Window to Speech frame s
*/

void WeightCepstrum (Vector c, int start, int count, int cepLiftering);
void UnWeightCepstrum(Vector c, int start, int count, int cepLiftering);
/*
   Apply weights w[1]..w[count] to c[start] to c[start+count-1] 
   where w[i] = 1.0 + (L/2.0)*sin(i*pi/L),  L=cepLiftering
*/

void PreEmphasise (Vector s, float k);
/*
   Apply first order preemphasis filter y[n] = x[n]-K*x[n-1 to s
*/

void Wave2LPC (Vector s, Vector a, Vector k, float *re, float *te);
/*
   Calculate LP Filter Coef in a and LP Refl Coef in k from speech s
   Either a and k can be NULL.  Residual Energy is returned in re and
   total energy in te.
*/

void LPC2RefC (Vector a, Vector k);
void RefC2LPC (Vector k, Vector a);
/*
   Transfer between filter and reflection coefs 
*/

void LPC2Cepstrum (Vector a, Vector c);
/*
   Calculate LP Cepstral Coef from  LP Filter Coef in a
*/

void FVec2Spectrum (Vector f, Vector s);
/*
   Pads f with zeroes and applies FFT to give spectrum s
   Only the useful half of the spectrum is returned eg 
   if VectorSize(s)=128 then a 128 point FFT will be used
   but only the first 64 complex points are returned in s
*/

void FFT(Vector s, int invert);
/*
   When called s holds nn complex values stored in the
   sequence   [ r1 , i1 , r2 , i2 , .. .. , rn , in ] where
   n = VectorSize(s) DIV 2, n must be a power of 2. On exit s
   holds the fft (or the inverse fft if invert == 1) - source
   Numerical Recipes Four1 page 411
*/

void Realft (Vector s);
/*
   When called s holds 2*n real values, on exit s holds the
   first  n complex points of the spectrum stored in
   the same format as for fft
*/
   
void SpecModulus(Vector s, Vector m);
void SpecLogModulus(Vector s, Vector m, int invert);
void SpecPhase(Vector s, Vector m);
/*
   On entry, s should hold n complex points; VectorSize(s)=n*2
   On return, m holds (log) modulus/phase of s in first n points
*/


/* ------------------------ End of HSigP.h ------------------------- */
