/* ----------------------------------------------------------- */
/*                   HTK  -  HMM Toolkit                       */
/* ----------------------------------------------------------- */
/*         Copyright: D. Rainton      June 1991                */
/*         ATR Interpreting Telephony Research Labs            */
/*                                                             */
/*                                                             */
/* Permission is hereby granted to copy, use and modify this   */
/* software provided that this banner notice is not removed    */
/*                                                             */
/* ----------------------------------------------------------- */
/*         File: HSubS.h  HMM Subspace Definition Data Type    */
/* ----------------------------------------------------------- */

/* 
   The following types define the in-memory representation of an 
   HMM subspace, for the corresponding external text file format
   see HSubS.c.
*/


typedef struct {
int vsz;
Matrix eig;
Vector mean;
} SubSDef;

/* this reads and loads  a subspace definition file */ 
void SubSOpen(char *fname, SubSDef *SubS);

/* creates an empty subspace structure */
void SubSCreate (int vsz, SubSDef *SubS);

/* this rotates in place a sequence of data vectors */
void RotateData(int start, int stop, DataFile *data, SubSDef SubS);

/* this rotates one vector, producing a new rotated vector */
void RotateVector(Vector in, Vector out, SubSDef SubS);

/* this recursively updates a correlation matrix and mean vector */
void UpdateCov (Vector x, Vector m, Matrix c, int n, int sz);

/* compute the SVD of the matrix a (from numerical recipies svdcmp.c) */
void SvdCmp(Matrix a, Vector w, Matrix v);

/* write the subspace  SubS to the file fname */
void SubSWrite (char *fname, SubSDef SubS);

/* write the subspace SubS to stdout */
void PrintSubS (SubSDef SubS);


