/* ----------------------------------------------------------- */
/*                   HTK  -  HMM Toolkit                       */
/* ----------------------------------------------------------- */
/*         Copyright: David Rainton    September 1991          */
/*         Last Update:                                        */
/*                                                             */
/*         ATR Interpreting Telephony Research Labs            */
/*         Japan                                               */
/*                                                             */
/* Permission is hereby granted to copy, use and modify this   */
/* software provided that this banner notice is not removed    */
/*                                                             */
/*  D. Rainton - Modification History                          */
/*                                                             */
/*                                                             */
/* ----------------------------------------------------------- */
/*         File: HUtilities.h: Misclaneous routines for GPD    */
/* ----------------------------------------------------------- */

typedef struct{
       int vSize;            /* data vector size */
       int M;                /* number of mixtures */
       CovKind CK;           /* covariance kind of all units */
       SampKind SK;          /* sample kind of all units */
       Boolean isTied;       /* true if tied mixtures */
       int maxStates;        /* max num states in any phone model */
     } _HMMParameters;

typedef _HMMParameters HMMParameters;

/* GetChkedInt: used to check that integer command line arguments are within the 
                specified range min->max */
int GetChkedInt(int min, int max, char * swtname);


/* GetChkedFlt: used to check that floating point command line arguments are within the 
                specified range min->max*/
float GetChkedFlt(float min, float max, char * swtname);  

/* CheckData: check a given data file for consistency with vSize and SK*/
void CheckData(DataFile *data, char *fn, int vSize, SampKind SK);

/* LoadHMM: load specified hmm, adding hmmExt if set. Set vSize, M, CK, SK, if vSize=0 on calling. Update
            maxStates*/
void LoadHMM(char *name, HMMDef *def, char *hmmDir, char *hmmExt, HMMParameters *hmmP);

/* LoadHMMDefs: create HMMdefList and load it */
HMMDef * LoadHMMDefs(LabId *HMMidList, int H, char *hmmDir, char *hmmExt, HMMParameters *hmmP);

/* MallocHMMDefList: malloc space for  HMMdefList and return  pointer to the calling routine */
HMMDef * MallocHMMDefList(HMMDef * HMMdefList, int H);

/* SaveHMMDefs: save the list of HMM definitions in HMMdefList to the directory hmmDir */
void SaveHMMDefs(HMMDef *HMMdefList, LabId *HMMidList, char *hmmDir, char *hmmExt, int H);

/* PrintTranscription: print a label file transcription to stdout */
void PrintTranscription(Transcription t);

/*HMMMixtureExists: check to see if a mixture exits */
Boolean HMMMixtureExists(HMMDef *hmm, int state, int mixture);

/* sqr: return x^2 */
double sqr(double x);

/* NormaliseVector: normalise a vector */
void NormaliseVector(Vector x, int size);

/*ClampVector: if a vector element falls below threshold set to threshold*/
void ClampVector(Vector x, int size, float threshold, float clampvalue);

/*ClampVectorToZero: if a vector element falls below threshold set to zero*/
void ClampVectorToZero(Vector x, int size, float threshold);

/*AddVectors: returns the result v1+v2 in v1*/ 
void AddVectors(Vector v1, Vector v2);

/*SubtractVectors: returns the result v1-v2 in v1*/ 
void SubtractVectors(Vector v1, Vector v2);

/*AddMatrices: returns the result m1+m2 in m1*/ 
void AddMatrices(Matrix m1, Matrix m2);

/*VectorMultiply: multiplies the vector v by the constant k*/ 
void VectorMultiply(Vector v, double k);

/*VectorDivide: divides the vector v by the constant k*/ 
void VectorDivide(Vector v, double k);

/*VectorSubtract: subtracts the constant k from each element of the vector v*/ 
void VectorSubtract(Vector v, double k);

/*VectorAdd: adds the constant k to each element of the vector v*/ 
void VectorAdd(Vector v, double k);

/*VectorL2F: Convert log(v) to real. Result is
   floored to 0.0 if x < LSMALL */ 
void VectorL2F(Vector v);

/*Vector2Norm: Returns the (sum_1^N v[i]^2)^(1/2)  */
double Vector2Norm(Vector v);

/*Vector1Norm: Returns the sum_1^N |v[i]| */
double Vector1Norm(Vector v);


/*VectorAbsMax: Returns max(abs(v[i])) */
double VectorAbsMax(Vector v);


/*DRHPrint: Print the model hmm according to specified flags */
void DRHPrint(HMMDef *hmm, int flags, ...);


