/* ----------------------------------------------------------- */
/*                   HTK  -  HMM Toolkit                       */
/* ----------------------------------------------------------- */
/*         Copyright: Steve Young      October 1989            */
/*         CoAuthor:  Val Beattie                              */
/*         Last Modified:              Sept 1990               */
/*                                                             */
/*         Cambridge University Engineering Department         */
/*         Trumpington Street, Cambridge, CB2 1PZ              */
/*                                                             */
/* Permission is hereby granted to copy, use and modify this   */
/* software provided that this banner notice is not removed    */
/*                                                             */
/* ----------------------------------------------------------- */
/*         File: HKMeans.h: K-Means Clustering Module          */
/* ----------------------------------------------------------- */



/* The following types allow an arbitrary subset of vectors
   stored in HDBase (a pool) to be defined and clusters within
   a pool.  Both pools and clusters grow dynamically although
   only pools can be added to externally.
*/

typedef struct {  /* identifies a unique vector in HDBase */
   int sequence;  /* its sequence number [0..NumSequences-1] */
   int index;     /* its index  [0..SequenceLength(sequence)-1] */
}VecInfo;

typedef struct {  /* defines a pool of vectors */
   int poolSpace; /*  number elements allocated in vi */
   int poolSize;  /*  number of vectors in pool */
   VecInfo *vi;   /*  array[1..poolSize] of VecInfo */
}VectorPool;

typedef struct {  /* defines a cluster within some assumed VectorPool */
   int numItems;  /*  num items in this cluster */
   int itemSpace; /*  number of elements allocated in items */
   int curCtr;    /*  item index of current cluster centre */
   Vector vCtr;   /*  actual cluster centre vector */
   int newCtr;    /*  item index new cluster centre */
   float aveRad;  /*  average radius of cluster */
   int pt1,pt2;   /*  two points on periphery */
   int *items;    /*  array[0..numItems-1] of index to pool element */
}Cluster; 

typedef struct {  /* defines a set of clusters */
   int numClust;  /*  num clusters */
   Cluster *cl;   /*  array[0..numClust-1] of Cluster */
}ClusterSet;   

#define GetPoolVector(vi) (GetDBVector(vi.sequence,vi.index))
/*
   Return the vector defined by vi
*/

void CreateVectorPool(VectorPool *vp);
void AddToVectorPool(VecInfo vi, VectorPool *vp);
void FreeVectorPool(VectorPool *vp);
/*
   Basic VectorPool operations.  The size of the pool
   grows dynamically as vi's are added
*/

void CreateClustSet(ClusterSet *cset, VectorPool *pool, 
                    int numCl, int maxIter, int vecSize);
/* 
   Creates a cluster set with numCl clusters using the given vector pool.
   The K-Means algorithm is used and MaxIter sets an upper limit on 
   convergence.
*/

void FreeClustSet(ClusterSet *cset);
/* 
   Frees the space allocated to cset 
*/

void DumpClustSet(ClusterSet *cset, VectorPool *pool);
/* 
   Print the given cluster set 
*/
               
/* ------------------------- End of HKMeans.h --------------------------- */
